import 'package:flutter/material.dart';
import 'package:xinlake_qrcode/xinlake_qrcode.dart';

class CameraScanDemo extends StatefulWidget {
  const CameraScanDemo({Key? key}) : super(key: key);

  @override
  State<CameraScanDemo> createState() => _CameraScanState();
}

class _CameraScanState extends State<CameraScanDemo> {
  String? _prefix;
  bool _playBeep = true;
  bool _frontFace = false;

  String? _qrcode; // from camera
  List<String>? _codeList; // from images

  void _fromCamera() async {
    final qrcode = await XinlakeQrcode.fromCamera(
      prefix: _prefix,
      playBeep: _playBeep,
      frontFace: _frontFace,
    );
    setState(() => _qrcode = qrcode);
  }

  void _fromImage() async {
    final codeList = await XinlakeQrcode.fromImage();
    setState(() => _codeList = codeList);
  }

  Widget _buildFromCamera() {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(10),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            TextField(
              decoration: const InputDecoration(
                label: Text("Prefix"),
                border: OutlineInputBorder(
                  borderSide: BorderSide(color: Colors.grey, width: 0.0),
                ),
              ),
              onChanged: (value) {
                _prefix = value;
              },
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const Text("Play beep"),
                Switch(
                  value: _playBeep,
                  onChanged: (value) => setState(() => _playBeep = value),
                ),
              ],
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const Text("Use front camera"),
                Switch(
                  value: _frontFace,
                  onChanged: (value) => setState(() => _frontFace = value),
                ),
              ],
            ),
            const SizedBox(height: 10),
            ElevatedButton(
              onPressed: _fromCamera,
              child: const Text("Scan QRCode"),
            ),
            const SizedBox(height: 10),
            Text(
              _qrcode ?? "NULL",
              softWrap: true,
              textAlign: TextAlign.center,
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildFromImage() {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(10),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            ElevatedButton(
              onPressed: _fromImage,
              child: const Text("From Images"),
            ),
            _codeList != null
                ? _codeList!.isNotEmpty
                    ? Column(
                        children: List<Widget>.generate(
                          _codeList!.length,
                          (index) => Text(_codeList![index]),
                        ),
                      )
                    : const Text("EMPTY", textAlign: TextAlign.center)
                : const Text("NULL", textAlign: TextAlign.center),
          ],
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (context, constraints) {
        return SingleChildScrollView(
          padding: const EdgeInsets.all(10),
          child: Column(
            children: [
              _buildFromCamera(),
              const SizedBox(height: 10),
              _buildFromImage(),
            ],
          ),
        );
      },
    );
  }
}
